pygeodesy.geodesicx.gx

Package pygeodesy :: Package geodesicx :: Module gx |
[frames] | no frames]

# Module gx

A pure Python version of Karney's C++ class GeodesicExact.

Class GeodesicExact follows the naming, methods and return values of class `Geodesic` from Karney's Python geographiclib.

Copyright (C) Charles Karney (2008-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 25.09.16

Classes
| GeodesicExact A pure Python version of Karney's C++ class GeodesicExact, modeled after Karney's Python class geodesic.Geodesic.
| GeodesicLineExact A pure Python version of Karney's C++ class GeodesicLineExact, modeled after Karney's Python class geodesicline.GeodesicLine.